{% load i18n %}

<div class="flex items-center ">
    <div class="block mr-3 outline rounded-full ml-1 h-1 w-1 {% if value == '' or value == None %}bg-base-500 outline-gray-500/20{% elif value %}bg-green-500 outline-green-200 dark:outline-green-500/20{% else %}bg-red-500 outline-red-200 dark:outline-red-500/20{% endif %}"></div>

    <span>
        {% if value == '' or value == None %}
            {% trans 'Unknown' %}
        {% elif value %}
            {% trans 'True' %}
        {% else %}
            {% trans 'False' %}
        {% endif %}
    </span>
</div>
