{% if form_show_errors and field.errors %}
    {% for error in field.errors %}
        <span id="error_{{ forloop.counter }}_{{ field.auto_id }}" class="block text-red-600 text-xs mt-1 dark:text-red-500">
            {{ error }}
        </span>
    {% endfor %}
{% endif %}
