{% extends "admin/base_site.html" %}
{% load admin_urls i18n static %}

{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}">{% endblock %}

{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="px-12">
            <div class="container mb-12 mx-auto -my-3">
                <ul class="flex flex-wrap">
                    {% url 'admin:index' as link %}
                    {% trans 'Home' as name %}
                    {% include 'unfold/helpers/breadcrumb_item.html' with link=link name=name %}

                    {% translate 'Change password' as breadcrumb_name %}
                    {% include 'unfold/helpers/breadcrumb_item.html' with link='' name=breadcrumb_name %}
                </ul>
            </div>
        </div>
    {% endblock %}
{% endif %}

{% block content %}
    <div id="content-main">
        <p class="bg-primary-100 mb-8 text-primary-600 px-3 py-3 rounded-default text-sm">
            {% translate 'Your password was changed.' %}
        </p>
    </div>
{% endblock %}
