{% extends "admin/base_site.html" %}
{% load admin_urls i18n static %}

{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}">{% endblock %}
{% block bodyclass %}{{ block.super }} {{ opts.app_label }}-{{ opts.model_name }} change-form{% endblock %}

{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="px-12">
            <div class="container mb-12 mx-auto -my-3">
                <ul class="flex flex-wrap">
                    {% url 'admin:index' as link %}
                    {% trans 'Home' as name %}
                    {% include 'unfold/helpers/breadcrumb_item.html' with link=link name=name %}

                    {% url 'admin:app_list' app_label=opts.app_label as link %}
                    {% include 'unfold/helpers/breadcrumb_item.html' with link=link name=opts.app_config.verbose_name %}

                    {% url opts|admin_urlname:'changelist' as link %}
                    {% include 'unfold/helpers/breadcrumb_item.html' with link=link name=opts.verbose_name_plural|capfirst %}

                    {% url opts|admin_urlname:'change' original.pk|admin_urlquote as link %}
                    {% include 'unfold/helpers/breadcrumb_item.html' with link=link name=original|truncatewords:"18" %}

                    {% translate 'Change password' as breadcrumb_name %}
                    {% include 'unfold/helpers/breadcrumb_item.html' with link='' name=breadcrumb_name %}
                </ul>
            </div>
        </div>
    {% endblock %}
{% endif %}

{% block content %}
    <div id="content-main">
        <form{% if form_url %} action="{{ form_url }}"{% endif %} method="post" id="{{ opts.model_name }}_form">{% csrf_token %}{% block form_top %}{% endblock %}
            <input type="text" name="username" value="{{ original.get_username }}" class="hidden">

            {% if is_popup %}
                <input type="hidden" name="{{ is_popup_var }}" value="1">
            {% endif %}

            {% include "unfold/helpers/messages/errornote.html" with errors=form.errors %}

            {% blocktranslate with username=original asvar message %}Enter a new password for the user <strong>{{ username }}</strong>.{% endblocktranslate %}
            {% include "unfold/helpers/messages/info.html" with message=message %}

            <fieldset class="border border-base-200 mb-8 rounded-default pt-3 px-3 shadow-xs dark:border-base-800">

                {% include "unfold/helpers/field.html" with field=form.password1 %}

                {% include "unfold/helpers/field.html" with field=form.password2 %}
            </fieldset>

            <button type="submit" class="bg-primary-600 border border-transparent font-medium px-3 py-2 rounded-default text-sm text-white">
                {% translate 'Change password' %}
            </button>
        </form>
    </div>
{% endblock %}
